import * as Guard from "../Guard";
import * as ToTypeNode from "../toTypeNode";
import * as Reference from "./Reference";
export const generateTypeNode = (entryPoint, currentPoint, factory, name, header, context, converterContext) => {
    return factory.TypeAliasDeclaration.create({
        export: true,
        name: converterContext.escapeDeclarationText(name),
        type: ToTypeNode.convert(entryPoint, currentPoint, factory, header.schema || { type: "null" }, context, converterContext),
    });
};
export const generatePropertySignature = (entryPoint, currentPoint, factory, name, header, context, converterContext) => {
    if (Guard.isReference(header)) {
        const reference = Reference.generate(entryPoint, currentPoint, header);
        if (reference.type === "local") {
            context.setReferenceHandler(currentPoint, reference);
            return factory.PropertySignature.create({
                name: converterContext.escapePropertySignatureName(name),
                optional: false,
                type: factory.TypeReferenceNode.create({
                    name: context.resolveReferencePath(currentPoint, reference.path).name,
                }),
            });
        }
        return factory.PropertySignature.create({
            name: converterContext.escapePropertySignatureName(name),
            optional: false,
            type: factory.TypeReferenceNode.create({
                name: context.resolveReferencePath(currentPoint, reference.path).name,
            }),
        });
    }
    return factory.PropertySignature.create({
        name: converterContext.escapePropertySignatureName(name),
        optional: false,
        type: ToTypeNode.convert(entryPoint, currentPoint, factory, header.schema || { type: "null" }, context, converterContext),
    });
};
export const generatePropertySignatures = (entryPoint, currentPoint, factory, headers, context, converterContext) => {
    return Object.entries(headers).map(([headerName, header]) => {
        return generatePropertySignature(entryPoint, currentPoint, factory, headerName, header, context, converterContext);
    });
};
export const generateInterface = (entryPoint, currentPoint, factory, name, headers, context, converterContext) => {
    return factory.InterfaceDeclaration.create({
        export: true,
        name: converterContext.escapeDeclarationText(name),
        comment: `@see https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.1.0.md#headerObject`,
        members: generatePropertySignatures(entryPoint, currentPoint, factory, headers, context, converterContext),
    });
};
//# sourceMappingURL=Header.js.map