import * as Guard from "../Guard";
import * as ToTypeNode from "../toTypeNode";
import * as Reference from "./Reference";
export const generateTypeNode = (entryPoint, currentPoint, factory, parameter, context, converterContext) => {
    return ToTypeNode.convert(entryPoint, currentPoint, factory, parameter.schema || { type: "null" }, context, converterContext);
};
export const generateTypeAlias = (entryPoint, currentPoint, factory, name, parameter, context, converterContext) => {
    return factory.TypeAliasDeclaration.create({
        export: true,
        name: converterContext.escapeDeclarationText(name),
        comment: parameter.description,
        type: generateTypeNode(entryPoint, currentPoint, factory, parameter, context, converterContext),
    });
};
export const generatePropertySignature = (entryPoint, currentPoint, store, factory, parameter, context, converterContext) => {
    if (Guard.isReference(parameter)) {
        const reference = Reference.generate(entryPoint, currentPoint, parameter);
        if (reference.type === "local") {
            context.setReferenceHandler(currentPoint, reference);
            const localRef = store.getParameter(reference.path);
            return factory.PropertySignature.create({
                name: converterContext.escapePropertySignatureName(localRef.name),
                optional: false,
                type: factory.TypeReferenceNode.create({
                    name: context.resolveReferencePath(currentPoint, reference.path).name,
                }),
            });
        }
        const isPathProperty = reference.data.in === "path";
        return factory.PropertySignature.create({
            name: converterContext.escapePropertySignatureName(reference.data.name),
            optional: isPathProperty ? false : !reference.data.required,
            type: ToTypeNode.convert(entryPoint, reference.referencePoint, factory, reference.data.schema || { type: "null" }, context, converterContext),
        });
    }
    const isPathProperty = parameter.in === "path";
    return factory.PropertySignature.create({
        name: converterContext.escapePropertySignatureName(parameter.name),
        optional: isPathProperty ? false : !parameter.required,
        type: ToTypeNode.convert(entryPoint, currentPoint, factory, parameter.schema || { type: "null" }, context, converterContext),
    });
};
export const generatePropertySignatures = (entryPoint, currentPoint, store, factory, parameters, context, converterContext) => {
    return parameters.map(parameter => {
        return generatePropertySignature(entryPoint, currentPoint, store, factory, parameter, context, converterContext);
    });
};
export const generateInterface = (entryPoint, currentPoint, store, factory, name, parameters, context, converterContext) => {
    return factory.InterfaceDeclaration.create({
        export: true,
        name,
        comment: `@see https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.1.0.md#headerObject`,
        members: generatePropertySignatures(entryPoint, currentPoint, store, factory, parameters, context, converterContext),
    });
};
/**
 * Alias作成用
 */
export const generateAliasInterface = (entryPoint, currentPoint, store, factory, name, parameters, context, converterContext) => {
    return factory.InterfaceDeclaration.create({
        export: true,
        name: converterContext.escapeDeclarationText(name),
        comment: `@see https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.1.0.md#headerObject`,
        members: generatePropertySignatures(entryPoint, currentPoint, store, factory, parameters, context, converterContext),
    });
};
//# sourceMappingURL=Parameter.js.map