import { EOL } from "os";
import { DevelopmentError } from "../../../Exception";
const httpMethodList = ["get", "put", "post", "delete", "options", "head", "patch", "trace"];
export const create = (rootSchema) => {
    if (!rootSchema.paths) {
        throw new DevelopmentError("pathsの存在しないところで利用しないでください");
    }
    const state = {};
    Object.entries(rootSchema.paths).forEach(([requestUri, pathItem]) => {
        httpMethodList.forEach(httpMethod => {
            const operation = pathItem[httpMethod];
            if (!operation) {
                return;
            }
            if (!operation.operationId) {
                return;
            }
            state[operation.operationId] = {
                httpMethod,
                requestUri,
                comment: [operation.summary, operation.description].filter(Boolean).join(EOL),
                deprecated: !!operation.deprecated,
                requestBody: operation.requestBody,
                parameters: operation.parameters,
                responses: operation.responses,
            };
        });
    });
    return state;
};
//# sourceMappingURL=Operation.js.map